@@ -1,4 +1,5 @@
 from enum import Enum
+from inspect import isclass
 from typing import Type, Optional
 
 from schemey.enum_schema import EnumSchema
@@ -12,6 +13,6 @@ PERMITTED_TYPES = [str, bool, int, float, NONE_TYPE]
 
 class EnumSchemaFactory(SchemaFactoryABC):
 
-    def create(self, type_: Type[T], context: SchemaContext) -> Optional[SchemaABC[T]]:
-        if issubclass(type_, Enum):
-            return EnumSchema(type_)
+    def create(self, type_: Type[T], default_value: T, context: SchemaContext) -> Optional[SchemaABC[T]]:
+        if isclass(type_) and issubclass(type_, Enum):
+            return EnumSchema(type_, default_value=default_value)
