@@ -7,4 +7,4 @@ T = TypeVar('T')
 @dataclass(frozen=True)
 class SchemaKey(Generic[T]):
     type: Type[T]
-    default_value: Optional[T]
+    default_value_hash: Optional[str]
