@@ -6,6 +6,7 @@ import validators
 from marshy.types import ExternalItemType
 
 from schemey._util import filter_none
+from schemey.graphql.graphql_attr import GraphqlAttr
 from schemey.json_output_context import JsonOutputContext
 from schemey.schema_abc import SchemaABC
 from schemey.string_format import StringFormat
@@ -38,6 +39,9 @@ class StringSchema(SchemaABC[str]):
             default=self.default_value
         ))
 
+    def to_graphql_attr(self) -> GraphqlAttr:
+        return GraphqlAttr('String')
+
     def get_schema_errors(self, item: str, current_path: Optional[List[str]] = None) -> Iterator[SchemaError]:
         if not isinstance(item, str):
             yield SchemaError(current_path, 'type', item)
